==> julia-git-graphs-src-1.13.0-1-any.pkg.tar.zst: usr/share/julia/arch-site/Graphs/test/parallel/distance.jl <==
@testset "Parallel.Distance" begin
    g4 = path_digraph(5)
    adjmx1 = [0 1 0; 1 0 1; 0 1 0] # graph
    adjmx2 = [0 1 0; 1 0 1; 1 1 0] # digraph
    a1 = SimpleGraph(adjmx1)
    a2 = SimpleDiGraph(adjmx2)
    distmx1 = [Inf 2.0 Inf; 2.0 Inf 4.2; Inf 4.2 Inf]
    distmx2 = [Inf 2.0 Inf; 3.2 Inf 4.2; 5.5 6.1 Inf]

    for g in testgraphs(a1)
        z = @inferred(Graphs.eccentricity(g, distmx1))
        y = @inferred(Parallel.eccentricity(g, distmx1))
        @test isapprox(y, z)
        @test @inferred(Graphs.diameter(y)) ==
            @inferred(Parallel.diameter(g, distmx1)) ==
            6.2
        @test @inferred(Graphs.periphery(y)) ==
            @inferred(Parallel.periphery(g, distmx1)) ==
            [1, 3]
        @test @inferred(Graphs.radius(y)) == @inferred(Parallel.radius(g, distmx1)) == 4.2
        @test @inferred(Graphs.center(y)) == @inferred(Parallel.center(g, distmx1)) == [2]
    end

    for g in testdigraphs(a2)
        z = @inferred(Graphs.eccentricity(g, distmx2))
        y = @inferred(Parallel.eccentricity(g, distmx2))
        @test isapprox(y, z)
        @test @inferred(Graphs.diameter(y)) ==
            @inferred(Parallel.diameter(g, distmx2)) ==
            6.2
        @test @inferred(Graphs.periphery(y)) ==
            @inferred(Parallel.periphery(g, distmx2)) ==
            [1]
        @test @inferred(Graphs.radius(y)) == @inferred(Parallel.radius(g, distmx2)) == 4.2
        @test @inferred(Graphs.center(y)) == @inferred(Parallel.center(g, distmx2)) == [2]
    end
end

==> julia-git-graphs-src-1.13.1-1-any.pkg.tar.zst: usr/share/julia/arch-site/Graphs/test/parallel/distance.jl <==
@testset "Parallel.Distance" for parallel in [:threads, :distributed]
    g4 = path_digraph(5)
    adjmx1 = [0 1 0; 1 0 1; 0 1 0] # graph
    adjmx2 = [0 1 0; 1 0 1; 1 1 0] # digraph
    a1 = SimpleGraph(adjmx1)
    a2 = SimpleDiGraph(adjmx2)
    distmx1 = [Inf 2.0 Inf; 2.0 Inf 4.2; Inf 4.2 Inf]
    distmx2 = [Inf 2.0 Inf; 3.2 Inf 4.2; 5.5 6.1 Inf]

    for g in testgraphs(a1)
        z = @inferred(Graphs.eccentricity(g, distmx1))
        y = @inferred(Parallel.eccentricity(g, distmx1; parallel))
        @test isapprox(y, z)
        @test @inferred(Graphs.diameter(y)) ==
            @inferred(Parallel.diameter(g, distmx1)) ==
            6.2
        @test @inferred(Graphs.periphery(y)) ==
            @inferred(Parallel.periphery(g, distmx1)) ==
            [1, 3]
        @test @inferred(Graphs.radius(y)) == @inferred(Parallel.radius(g, distmx1)) == 4.2
        @test @inferred(Graphs.center(y)) == @inferred(Parallel.center(g, distmx1)) == [2]
    end

    let g = testgraphs(a1)[1]
        # An error should be reported if the parallel mode could not be understood
        @test_throws ArgumentError Parallel.eccentricity(g, distmx1; parallel=:thread)
        @test_throws ArgumentError Parallel.eccentricity(g, distmx1; parallel=:distriibuted)
    end

    for g in testdigraphs(a2)
        z = @inferred(Graphs.eccentricity(g, distmx2))
        y = @inferred(Parallel.eccentricity(g, distmx2; parallel))
        @test isapprox(y, z)
        @test @inferred(Graphs.diameter(y)) ==
            @inferred(Parallel.diameter(g, distmx2)) ==
            6.2
        @test @inferred(Graphs.periphery(y)) ==
            @inferred(Parallel.periphery(g, distmx2)) ==
            [1]
        @test @inferred(Graphs.radius(y)) == @inferred(Parallel.radius(g, distmx2)) == 4.2
        @test @inferred(Graphs.center(y)) == @inferred(Parallel.center(g, distmx2)) == [2]
    end
end
